Module IIpGraph

Module IIpGraph 

Module containing a contract’s types and functions.

interface IIpGraph {
    function addParentIp(address ipId, address[] parentIpIds) external;
    function hasParentIp(address ipId, address parentIpId) external view returns (bool);
    function getParentIps(address ipId) external view returns (address[] memory);
    function getParentIpsCount(address ipId) external view returns (uint256);
    function getAncestorIps(address ipId) external view returns (address[] memory);
    function getAncestorIpsCount(address ipId) external view returns (uint256);
    function hasAncestorIp(address ipId, address ancestorIpId) external view returns (bool);
    function setRoyalty(address ipId, address parentIpId, uint256 royaltyPolicyKind, uint256 royalty) external;
    function getRoyalty(address ipId, address ancestorIpId, uint256 royaltyPolicyKind) external view returns (uint256);
    function getRoyaltyStack(address ipId, uint256 royaltyPolicyKind) external view returns (uint256);
    function hasParentIpExt(address ipId, address parentIpId) external view returns (bool);
    function getParentIpsExt(address ipId) external view returns (address[] memory);
    function getParentIpsCountExt(address ipId) external view returns (uint256);
    function getAncestorIpsExt(address ipId) external view returns (address[] memory);
    function getAncestorIpsCountExt(address ipId) external view returns (uint256);
    function hasAncestorIpExt(address ipId, address ancestorIpId) external view returns (bool);
    function getRoyaltyExt(address ipId, address ancestorIpId, uint256 royaltyPolicyKind) external view returns (uint256);
    function getRoyaltyStackExt(address ipId, uint256 royaltyPolicyKind) external view returns (uint256);
}

Structs

addParentIpCall
Function with signature addParentIp(address,address[]) and selector 0x762eca33.
addParentIpReturn
Container type for the return parameters of the addParentIp(address,address[]) function.
getAncestorIpsCall
Function with signature getAncestorIps(address) and selector 0x7c976551.
getAncestorIpsCountCall
Function with signature getAncestorIpsCount(address) and selector 0x1c486366.
getAncestorIpsCountExtCall
Function with signature getAncestorIpsCountExt(address) and selector 0xdae55af8.
getAncestorIpsCountExtReturn
Container type for the return parameters of the getAncestorIpsCountExt(address) function.
getAncestorIpsCountReturn
Container type for the return parameters of the getAncestorIpsCount(address) function.
getAncestorIpsExtCall
Function with signature getAncestorIpsExt(address) and selector 0xbe14b92a.
getAncestorIpsExtReturn
Container type for the return parameters of the getAncestorIpsExt(address) function.
getAncestorIpsReturn
Container type for the return parameters of the getAncestorIps(address) function.
getParentIpsCall
Function with signature getParentIps(address) and selector 0x40e33d5b.
getParentIpsCountCall
Function with signature getParentIpsCount(address) and selector 0x5a5f66a9.
getParentIpsCountExtCall
Function with signature getParentIpsCountExt(address) and selector 0xd1335888.
getParentIpsCountExtReturn
Container type for the return parameters of the getParentIpsCountExt(address) function.
getParentIpsCountReturn
Container type for the return parameters of the getParentIpsCount(address) function.
getParentIpsExtCall
Function with signature getParentIpsExt(address) and selector 0x2b6d6e54.
getParentIpsExtReturn
Container type for the return parameters of the getParentIpsExt(address) function.
getParentIpsReturn
Container type for the return parameters of the getParentIps(address) function.
getRoyaltyCall
Function with signature getRoyalty(address,address,uint256) and selector 0xa987a481.
getRoyaltyExtCall
Function with signature getRoyaltyExt(address,address,uint256) and selector 0xde87777d.
getRoyaltyExtReturn
Container type for the return parameters of the getRoyaltyExt(address,address,uint256) function.
getRoyaltyReturn
Container type for the return parameters of the getRoyalty(address,address,uint256) function.
getRoyaltyStackCall
Function with signature getRoyaltyStack(address,uint256) and selector 0x65b55e26.
getRoyaltyStackExtCall
Function with signature getRoyaltyStackExt(address,uint256) and selector 0xa7624eb1.
getRoyaltyStackExtReturn
Container type for the return parameters of the getRoyaltyStackExt(address,uint256) function.
getRoyaltyStackReturn
Container type for the return parameters of the getRoyaltyStack(address,uint256) function.
hasAncestorIpCall
Function with signature hasAncestorIp(address,address) and selector 0x10487a6c.
hasAncestorIpExtCall
Function with signature hasAncestorIpExt(address,address) and selector 0x3c71acae.
hasAncestorIpExtReturn
Container type for the return parameters of the hasAncestorIpExt(address,address) function.
hasAncestorIpReturn
Container type for the return parameters of the hasAncestorIp(address,address) function.
hasParentIpCall
Function with signature hasParentIp(address,address) and selector 0x152f6be9.
hasParentIpExtCall
Function with signature hasParentIpExt(address,address) and selector 0xd5a1fc52.
hasParentIpExtReturn
Container type for the return parameters of the hasParentIpExt(address,address) function.
hasParentIpReturn
Container type for the return parameters of the hasParentIp(address,address) function.
setRoyaltyCall
Function with signature setRoyalty(address,address,uint256,uint256) and selector 0xd9139f19.
setRoyaltyReturn
Container type for the return parameters of the setRoyalty(address,address,uint256,uint256) function.

Enums

IIpGraphCalls
Container for all the IIpGraph function calls.